.. StagPy documentation master file, created by
   sphinx-quickstart on Fri Feb 19 19:57:27 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to StagPy's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   sources/install
   sources/tuto
   sources/stagyydata
   sources/cli
   sources/cookbook
   sources/developers
   sources/maintainers


